@@ -1904,7 +1904,7 @@ class Update(MethodsInterface):
 
     def update_increment_current_level(self):
         #TODO add translation
-        self.startTask(_("Increasing update level"))
+        self.startTask(_("Using higher update level"))
         self._update_increment_current_level()
         self.set_migration_mode(False)
         # self.unstash_binhost()
