@@ -18,7 +18,7 @@ import sys
 from calculate.core.server.func import Action
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError
-from calculate.update.update import UpdateError
+from ..update import UpdateError
 from calculate.lib.utils.git import GitError
 
 _ = lambda x: x
